@@ -246,7 +246,6 @@ def run_tests(sandbox_dir, packages, options):
             print >>fp, 'Executing %s' % cmd
         status = os.system(cmd)
 
-
         # Here starts the funny parts: 
         # analysis of the Zope 2.11+ testrunner logfile
 
@@ -291,7 +290,6 @@ def run_tests(sandbox_dir, packages, options):
         mo_f = failures.search(status_line)
 
         if mo_e or mo_f:
-            tests_failed += 1
             num_errors = num_failures = 0
             if mo_e: 
                 num_errors = int(mo_e.group(1))
@@ -299,8 +297,8 @@ def run_tests(sandbox_dir, packages, options):
             if mo_f: 
                 num_failures = int(mo_f.group(1))
                 d['number_failures'] += num_failures
-            d['tests_ok'] = (num_failures+num_errors == 0)
-
+            d['tests_ok'] = (num_failures + num_errors == 0)
+            tests_failed += (num_failures + num_errors != 0)
 
         # write test specific logfile
         fn = os.path.join(options.log_dir, normalize(package) + '.txt')
